// Generated by dts-bundle-generator v9.5.1

import { z } from 'zod';

export declare class MuseError extends Error {
	fmt(): string;
}
export declare class MusePluginError extends MuseError {
	plugin: string;
	constructor(message: string, plugin: string);
	fmt(): string;
}
export declare class MuseFileError extends MuseError {
	filePath: string;
	constructor(message: string, filePath: string);
	fmt(): string;
}
export declare class MuseFileNotFoundError extends MuseFileError {
	constructor(filePath: string);
}
export declare class CLIError extends MuseError {
}
export interface LoadedFile {
	content: string;
	filePath: string;
	fileType: string;
	dirname: string;
	basename: string;
	mimeType: string;
}
export declare function loadFileContent(filePath: string): Promise<LoadedFile>;
export type UnknownRecord = Record<string, unknown>;
/**
 * Parse one or more YAML documents from a string
 *
 * @param text - The YAML string to parse
 * @returns - An array of parsed objects
 */
export declare function parseYAMLEntries(text: string): UnknownRecord[];
/**
 * Parse one or more JSON documents from a string
 *
 * @param text - The JSON string to parse
 * @returns - An array of parsed objects
 */
export declare function parseJSONEntries(text: string): UnknownRecord[];
/**
 * Parse one or more TOML documents from a string
 *
 * @param text - The TOML string to parse
 * @returns - An array of parsed objects
 */
export declare function parseTOMLEntries(text: string): UnknownRecord[];
/**
 * Parse one or more Markdown documents from a string
 *
 * @param text - The Markdown string to parse
 * @returns - An array of parsed objects
 */
export declare function parseMarkdownEntry(text: string, contentKey: string): UnknownRecord[];
export declare function autoParseEntry(loadedFile: LoadedFile, contentKey: string): UnknownRecord[];
export type MuseStepFn = (binding: Binding) => Promise<Binding>;
export interface MusePlugin {
	readonly filePath: string;
	readonly name: string;
	readonly description: string;
	readonly version: string;
	readonly step: MuseStepFn;
}
export declare function loadPlugin(bindingDirname: string, pluginPath: string): Promise<MusePlugin>;
export declare const SourceSchema: z.ZodUnion<[
	z.ZodObject<{
		file: z.ZodString;
	}, "strip", z.ZodTypeAny, {
		file: string;
	}, {
		file: string;
	}>,
	z.ZodObject<{
		url: z.ZodString;
	}, "strip", z.ZodTypeAny, {
		url: string;
	}, {
		url: string;
	}>
]>;
export type SourceShorthand = z.infer<typeof SourceSchema>;
export declare function sourceShorthandToSource(shorthand: SourceShorthand): MuseSource;
export type SourceType = "file" | "url";
/** A descriptor of a location to load into a Muse binding */
export interface MuseSource {
	location: string;
	type: SourceType;
}
export interface SourceOptions {
	cwd: string;
	contentKey: string;
	ignore: string[];
}
/** A single loaded entry from a Muse source */
export interface MuseEntry<MetaShape = UnknownRecord> {
	_raw: string;
	location: string;
	data: Record<string, unknown>;
	meta: MetaShape;
	source: MuseSource;
}
export declare function parseMuseFile(rawFilePath: string, { contentKey }: SourceOptions): Promise<MuseEntry[]>;
export declare function loadFromSource(source: MuseSource, options: SourceOptions): Promise<MuseEntry[]>;
declare const BindingSchema: z.ZodObject<{
	contentKey: z.ZodDefault<z.ZodString>;
	sources: z.ZodDefault<z.ZodArray<z.ZodUnion<[
		z.ZodObject<{
			file: z.ZodString;
		}, "strip", z.ZodTypeAny, {
			file: string;
		}, {
			file: string;
		}>,
		z.ZodObject<{
			url: z.ZodString;
		}, "strip", z.ZodTypeAny, {
			url: string;
		}, {
			url: string;
		}>
	]>, "many">>;
	options: z.ZodDefault<z.ZodRecord<z.ZodString, z.ZodAny>>;
	processors: z.ZodDefault<z.ZodArray<z.ZodString, "many">>;
}, "strip", z.ZodTypeAny, {
	options: Record<string, any>;
	contentKey: string;
	sources: ({
		file: string;
	} | {
		url: string;
	})[];
	processors: string[];
}, {
	options?: Record<string, any> | undefined;
	contentKey?: string | undefined;
	sources?: ({
		file: string;
	} | {
		url: string;
	})[] | undefined;
	processors?: string[] | undefined;
}>;
/**
 * The core object of a Muse binding
 * Contains information about the binding file, the configuration of
 * the project, and a list of entries to be processed
 */
export interface Binding<MetaShape = UnknownRecord> {
	/** The raw data read from the binding file */
	readonly _raw: z.infer<typeof BindingSchema>;
	/** Information about the sources used to load entries */
	readonly sources: MuseSource[];
	/** The full file path to the binding file */
	readonly bindingPath: string;
	/** The key used to for default content in unstructured files */
	readonly contentKey: string;
	/** All entries loaded from the binding file */
	readonly entries: MuseEntry[];
	/** A list of processors to be applied to the entries */
	readonly plugins: MusePlugin[];
	/** Arbitrary metadata for processors to use to cache project data */
	readonly meta: MetaShape;
	/** Configuration options for Muse and all processors */
	readonly options: UnknownRecord;
}
export declare function loadBinding(initialPath: string): Promise<Binding>;
export declare class Muse {
	bindingLoaded: boolean;
	preliminaryBinding: Partial<Binding>;
	additionalSources: string[];
	additionalPluginPaths: string[];
	constructor(bindingConfig: Partial<Binding>);
	source(newSource: string): void;
	plugin(pluginPath: string): void;
}
export declare const DEFAULT_CONTENT_KEY = "content";

export {};
