// src/errors.ts
class MuseError extends Error {
  fmt() {
    return `-- ERROR -- 
Details: ${this.message}`;
  }
}

class MusePluginError extends MuseError {
  plugin;
  constructor(message, plugin) {
    super(message);
    this.plugin = plugin;
  }
  fmt() {
    return `-- PLUGIN ERROR --Plugin: ${this.plugin}
Details: ${this.message}`;
  }
}

class MuseFileError extends MuseError {
  filePath;
  constructor(message, filePath) {
    super(message);
    this.filePath = filePath;
  }
  fmt() {
    return `-- FILE ERROR --
File Path: ${this.filePath}
Details: ${this.message}`;
  }
}

class MuseFileNotFoundError extends MuseFileError {
  constructor(filePath) {
    super("File not found", filePath);
    this.message = "File does not exist";
    this.filePath = filePath;
  }
}

class CLIError extends MuseError {
}
// src/muse.ts
class Muse {
  bindingLoaded = false;
  preliminaryBinding = {};
  additionalSources = [];
  additionalPluginPaths = [];
  constructor(bindingConfig) {
    this.preliminaryBinding = bindingConfig;
  }
  source(newSource) {
    this.additionalSources.push(newSource);
  }
  plugin(pluginPath) {
    this.additionalPluginPaths.push(pluginPath);
  }
}

// src/exports.ts
var DEFAULT_CONTENT_KEY = "content";
export {
  MusePluginError,
  MuseFileNotFoundError,
  MuseFileError,
  MuseError,
  Muse,
  DEFAULT_CONTENT_KEY,
  CLIError
};
